<?php

use \SearchWPModalFormUtils as Utils;
use \SearchWPModalFormSettings as Settings;
use \SearchWPModalFormNotice as Notice;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class SearchWPModalFormSettings_Api.
 *
 * The SearchWP Modal Search Form settings API.
 *
 * @since 0.5.0
 */
class SearchWPModalFormSettingsApi {

	/**
	 * WP option name to save settings.
	 *
	 * @since 0.5.0
	 */
	const OPTION_NAME = 'searchwp_modal_form_settings';

	/**
	 * Capability requirement for managing settings.
	 *
	 * @since 0.5.0
	 */
	const CAPABILITY = 'manage_options';

	/**
	 * Hooks.
	 *
	 * @since 0.5.0
	 */
	public function hooks() {

		add_action( 'admin_init', [ $this, 'init' ] );
	}

	/**
	 * Init hook callback.
	 *
	 * @since 0.5.0
	 */
	public function init() {

		if ( Utils::is_settings_page() ) {
			$this->save_settings();
		}
	}

	/**
	 * Save settings.
	 *
	 * @since 0.5.0
	 */
	private function save_settings() {

		if ( ! $this->current_user_can_save() ) {
			return;
		}

		$fields   = $this->get_registered_settings();
		$settings = get_option( self::OPTION_NAME, [] );

		foreach ( $fields as $slug => $field ) {

			if ( empty( $field['type'] ) || $field['type'] === 'content' ) {
				continue;
			}

			// phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized, WordPress.Security.NonceVerification.Missing
			$value = isset( $_POST[ $slug ] ) ? trim( wp_unslash( $_POST[ $slug ] ) ) : false;

			$value = $this->sanitize_setting( $value, $field['type'] );

			// Add to settings.
			$settings[ $slug ] = $value;
		}

        update_option( self::OPTION_NAME, $settings );

		Notice::success( esc_html__( 'Settings were successfully saved.', 'searchwp-modal-search-form' ) );
	}

	/**
	 * Get settings capability.
	 *
	 * @since 0.5.0
	 *
	 * @return string
	 */
	public static function get_capability() {

		return (string) apply_filters( 'searchwp_modal_form_settings_capability', self::CAPABILITY );
	}

	/**
	 * Check if the current user can save settings.
	 *
	 * @since 0.5.0
	 *
	 * @return bool
	 */
	private function current_user_can_save() {

		// Check nonce and other various security checks.
		if ( ! isset( $_POST['searchwp-modal-form-settings-submit'] ) ) {
			return false;
		}

		if ( empty( $_POST['nonce'] ) ) {
			return false;
		}

		if ( ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'searchwp-modal-form-settings-nonce' ) ) {
			return false;
		}

		$capability = self::get_capability();

		if ( ! current_user_can( $capability ) ) {
			return false;
		}

		return true;
	}

	/**
	 * Get the value of a specific SearchWP setting.
	 *
	 * @since 0.5.0
	 *
	 * @param string $slug    Setting slug.
	 * @param mixed  $default Default setting value.
	 *
	 * @return mixed
	 */
	public function get( $slug, $default = null ) {

		$slug     = sanitize_key( $slug );
		$settings = get_option( self::OPTION_NAME );

		if ( $default === null ) {
			$registered = $this->get_registered_settings();
			$default    = isset( $registered[ $slug ]['default'] ) ? $registered[ $slug ]['default'] : $default;
		}

		return isset( $settings[ $slug ] ) ? wp_unslash( $settings[ $slug ] ) : $default;
	}

	/**
	 * Return all the default registered settings fields.
	 *
	 * @since 0.5.0
	 *
	 * @return array
	 */
	public function get_registered_settings() {

		$defaults = [
			'general-heading'      => [
				'slug'    => 'general-heading',
				'content' => '<h3>' . esc_html__( 'General', 'searchwp-modal-search-form' ) . '</h3>',
				'type'    => 'content',
				'class'   => [ 'section-heading' ],
			],
			'enable-modal-form'    => [
				'slug'       => 'enable-modal-form',
				'name'       => esc_html__( 'Enable Modal Form', 'searchwp-modal-search-form' ),
				'desc'       => esc_html__( 'Check this option to enable the Modal Search Form.', 'searchwp-modal-search-form' ),
				'type'       => 'checkbox',
				'default'    => true,
				'desc_after' => Settings::get_dyk_block_output(),
			],
			'modal-heading'        => [
				'slug'    => 'modal-heading',
				'content' => '<h3>' . esc_html__( 'Modal', 'searchwp-modal-search-form' ) . '</h3>',
				'type'    => 'content',
				'class'   => [ 'section-heading' ],
			],
			'include-frontend-css' => [
				'slug'    => 'include-frontend-css',
				'name'    => esc_html__( 'Include Styling', 'searchwp-modal-search-form' ),
				'desc'    => esc_html__( 'Determines which CSS files to load and use for the site. "Positioning and visual styling" is recommended, unless you are experienced with CSS or instructed by support to change settings.', 'searchwp-modal-search-form' ),
				'type'    => 'select',
				'default' => 'all',
				'options' => [
					'all'      => esc_html__( 'Positioning and visual styling', 'searchwp-modal-search-form' ),
					'position' => esc_html__( 'Positioning styling only', 'searchwp-modal-search-form' ),
					'none'     => esc_html__( 'No styling', 'searchwp-modal-search-form' ),
				],
			],
			'modal-fullscreen'     => [
				'slug' => 'modal-fullscreen',
				'name' => esc_html__( 'Full Screen Mode', 'searchwp-modal-search-form' ),
				'desc' => esc_html__( 'Check this option to make the modal cover the entire screen when open. This option is great to provide a distraction free search experience for your users.', 'searchwp-modal-search-form' ),
				'type' => 'checkbox',
			],
			'modal-disable-scroll' => [
				'slug' => 'modal-disable-scroll',
				'name' => esc_html__( 'Disable Scroll', 'searchwp-modal-search-form' ),
				'desc' => esc_html__( 'Check this option to disable background scrolling of the page when the modal is open.', 'searchwp-modal-search-form' ),
				'type' => 'checkbox',
			],
		];

		return apply_filters( 'searchwp_modal_form_settings_defaults', $defaults );
	}

	/**
	 * Save settings.
	 *
	 * @since 0.5.0
	 *
	 * @param mixed  $value      Value to sanitize.
	 * @param string $field_type Field type.
	 *
	 * @return bool|string
	 */
	private function sanitize_setting( $value, $field_type ) {

        switch ( $field_type ) {
            case 'checkbox':
                $value = (bool) $value;
                break;

            case 'select':
            default:
                $value = sanitize_text_field( $value );
                break;
        }

        return $value;
	}
}
